@@ -2,6 +2,8 @@ from django.contrib.auth import get_user_model
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
+from ..managers.rule import RuleManager
+
 User = get_user_model()
 
 
@@ -37,6 +39,7 @@ class BaseRuleModelMixin(models.Model):
         null=True,
         blank=True
     )
+    objects = RuleManager()
 
     def __str__(self):
         return f'{self.name} - {self.get_category_display()}'
